@@ -18,10 +18,14 @@
 
 from harmalysis.classes.key import Key
 
+
 class Harmalysis(object):
     established_key = Key("C", scale="major")
+
     def __init__(self):
         self.main_key = None
         self.secondary_key = None
         self.chord = None
-        self.tonicized_keys = []
\ No newline at end of file
+        self.tonicized_keys = []
+        self.implicit = False
+        self.alternative = False
